Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3258)

Unified Diff: chrome/browser/metrics/chromeos_metrics_provider.h

Issue 2958353002: [Cleanup] Migrate the StatisticsProvider to use the TaskScheduler (Closed)
Patch Set: rewrap a line Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/metrics/chromeos_metrics_provider.h
diff --git a/chrome/browser/metrics/chromeos_metrics_provider.h b/chrome/browser/metrics/chromeos_metrics_provider.h
index 293c0af4c57c9ec3468d81b577f4abca0f0cf078..9ed27564fa868c9fbbce29ed49260580b1a228c9 100644
--- a/chrome/browser/metrics/chromeos_metrics_provider.h
+++ b/chrome/browser/metrics/chromeos_metrics_provider.h
@@ -66,8 +66,8 @@ class ChromeOSMetricsProvider : public metrics::MetricsProvider {
metrics::ChromeUserMetricsExtension* uma_proto) override;
private:
- // Called on the FILE thread to load hardware class information.
- void InitTaskGetHardwareClassOnFileThread();
+ // Called on a background thread to load hardware class information.
+ void InitTaskGetHardwareClassOnBackgroundThread();
// Update the number of users logged into a multi-profile session.
// If the number of users change while the log is open, the call invalidates
« no previous file with comments | « chrome/browser/chromeos/chrome_browser_main_chromeos.cc ('k') | chrome/browser/metrics/chromeos_metrics_provider.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698